..
      Copyright (c) 2018 Rackspace, US Inc.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=======================================
Octavia Software Development Kits (SDK)
=======================================

Introduction
============

This is a list of known SDKs and language bindings that support OpenStack
load balancing via the Octavia API. This list is a "best effort" to keep
updated, so please check with your favorite SDK project to see if they
support OpenStack load balancing. If not, open a bug for them!

.. Note:: The projects listed here may not be maintained by the OpenStack
          LBaaS team. Please submit bugs for these projects through their
          respective bug tracking systems.

Java
====

`OpenStack4j <http://www.openstack4j.com/>`_

Python
======

`OpenStack SDK <https://docs.openstack.org/python-openstacksdk/latest/>`_
